#[repr(u8)]pub enum MegaSrPsr {
PSR_0 = 0,
PSR_1 = 1,
}Variants
PSR_0 = 0
The target subsystem was not powered down for the previous power-down request.
PSR_1 = 1
The target subsystem was powered down for the previous power-down request.
Implementations